@@ -1,22 +1,27 @@
-KnowB<-function(data, matrix=TRUE, cell=60, method="accumulation", curve= "Clench", estimator=1,
-cutoff=2, cutoffCompleteness= 0, cutoffSlope= 0.1, SpR=FALSE, largematrix=FALSE,
-cormatrix=FALSE, Area="World", extent=TRUE, minLon, maxLon, minLat, maxLat,
-colbg="#FFFFFF", colcon="#C8C8C8", colf="black", pro = TRUE, inc = 0.005, exclude = NULL,
-colexc = NULL, colfexc="black", colscale=c("#FFFFFFFF", "#C8FFFFFF","#64FFFFFF","#00FFFFFF",
-"#64FF64FF","#C8FF00FF", "#FFFF00FF","#FFC800FF","#FF6400FF","#FF0000FF"), legend.pos="y",
+KnowB<-function(data, format="A", cell=60,  curve= "Rational", estimator=1,
+cutoff=1, cutoffCompleteness= 0, cutoffSlope= 1, largematrix=FALSE,
+ Area="World", extent=TRUE, minLon, maxLon, minLat, maxLat,
+colbg="transparent", colcon="transparent", colf="black", pro = TRUE, inc = 0.005, exclude = NULL,
+colexc = NULL, colfexc="black", colscale=rev(heat.colors(100)), legend.pos="y",
 breaks=10, xl=0, xr=0, yb=0, yt=0, asp, lab = NULL, xlab = "Longitude", ylab = "Latitude",
-main1="Actual richness", main2="Predicted richness", main3="Residuals", main4="Records",
-main5="Completeness", main6="Slope", cex.main = 1.6, cex.lab = 1.4, cex.axis = 1.2, 
-family = "sans", font.main = 2, font.lab = 1, font.axis = 1, lwdP=0.6, lwdC=0.1, trans=c(1,1),
-log=c(0,0), ndigits=0, ini=NULL, end=NULL, ComCut=TRUE, SlopeCut=TRUE, file1 = "Actual richness.csv",
-file2 = "Predicted richness.csv", file3 = "Residuals.csv", file4 = "List of species.csv",
-file5 = "Species per site.csv", file6 = "Estimators.csv", file7 = "Species per record.csv",
-file8 = "Records.csv", file9 = "Completeness.csv", file10 = "Slope.csv", file11 = "Standard error of the estimators.csv",
-na = "NA", dec = ",", row.names = FALSE, fileEncoding = "", jpg=TRUE, jpg1="Actual richness.jpg",
-jpg2="Predicted richness.jpg", jpg3="Residuals.jpg", jpg4="Correlation matrix.jpg",
-jpg5="Records.jpg",  jpg6="Completeness.jpg", jpg7="Slope.jpg",cex=1.5, pch=15,
+main1="Observed richness", main2="Records",
+main3="Completeness", main4="Slope", cex.main = 1.6, cex.lab = 1.4, cex.axis = 1.2, cex.legend=1.2, family = "sans", font.main = 2, font.lab = 1, font.axis = 1, lwdP=0.6, lwdC=0.1, trans=c(1,1),
+log=c(0,0), ndigits=0,   save="CSV", file1 = "Observed richness",
+ file2 = "List of species", file3 = "Species per site", file4 = "Estimators", file5 = "Species per record",
+file6 = "Records", file7 = "Completeness", file8 = "Slope", file9 = "Standard error of the estimators",
+na = "NA", dec = ",", row.names = FALSE, jpg=TRUE, jpg1="Observed richness.jpg",
+jpg2="Records.jpg",  jpg3="Completeness.jpg", jpg4="Slope.jpg",cex=1.5, pch=15,
 cex.labels=1.5, pchcol="red", ask=FALSE){
 
+
+
+
+method<-"accumulation"
+
+SpR<-FALSE
+
+
+
 options(warn=-1)
 
 if(jpg==FALSE) par(ask=ask) else yuret<-1
@@ -28,13 +33,11 @@ adworld<-1
 stop("It is necessary to load data(adworld)")
 }
 
-
-
 if(Area!="World" & exists("adworld1")==FALSE){
 stop("It is necessary to use RWizard and replace data(adworld) by @_Build_AdWorld_, for using administative areas")
 }
 
-if(Area!="World" & exists("adworld2")==FALSE){
+if(!is.null(exclude)){
 stop("It is necessary to use RWizard and replace data(adworld) by @_Build_AdWorld_, for using administative areas")
 }
 
@@ -46,15 +49,22 @@ if(exists("adworld2")==FALSE){
 adworld2<-1
 }
 
+
 ####End Checking
 
-if(matrix==FALSE){
+if(format=="B"){
+data[is.na(data)]<-0
+}
+
+
+
+if(format=="A"){
 data[is.na(data)]<-0
 }
 x<-na.exclude(data)
 
-if(matrix==FALSE){
-matrix<-TRUE
+if(format=="B"){
+format<-"A"
 xLo<-x[,1]
 xLa<-x[,2]
 dimg<-dim(x[,c(-1,-2)])
@@ -71,7 +81,7 @@ x<-x[(x$Longitude!=0 & x$Latitude!=0),]
 }
 
 
-if(matrix==TRUE){
+if(format=="A"){
 if(method=="accumulation" | method=="incidence"){
 b<-x[,4]
 x<-x[rep(1:nrow(x[,1:3]), b), ] 
@@ -82,10 +92,19 @@ x[,4]<-1
 
 values1<-data.frame(1,2,3,4,5,6,7,8,9,10)
 values2<-data.frame(1,2,3,4,5,6,7)
-values3<-data.frame(1,2,3,4,5,6,7,8,9,10,11,12,13)
+
+if(estimator==0){
+values3<-data.frame(1,2,3,4,5,6,7,8,9,10)
+sevalues3<-data.frame(1,2,3,4,5,6,7,8)
+}
+else{
+values3<-data.frame(1,2,3,4,5,6,7)
+sevalues3<-data.frame(1,2,3,4,5,6)
+}
+
 sevalues1<-data.frame(1,2,3,4,5,6,7)
 sevalues2<-data.frame(1,2,3,4,5,6)
-sevalues3<-data.frame(1,2,3,4,5,6,7,8)
+
 salA<-data.frame(c(2,5,6,1,0,6,5,8,7,4,9,8), nrow=4)
 sal<-data.frame(c(2,5,6,1,0,6,5,8,7,4,9,8), nrow=4)
 cu2<-NA;cu3<-NA;cu4<-NA;cu5<-NA
@@ -93,7 +112,7 @@ sp2<-NA;sp3<-NA;sp4<-NA;sp5<-NA
 serandom<-NA;seexact<-NA;secoleman<-NA;serarefaction<-NA
 
 
-if(matrix==TRUE){
+if(format=="A"){
 re<-dim(x)
 
 Records<-seq(1,re[1],1)
@@ -175,29 +194,49 @@ datosac<-with(temp, table(temp[,5],temp[,1]))
 if(elements==0){
 }
 else{
-if(dec=="."){
-write.csv(x=datosf, file = file5, fileEncoding = fileEncoding,
-row.names=row.names,na=na)
-write.csv(x=datosac, file = file7, fileEncoding = fileEncoding,
-row.names=row.names,na=na)
+
+
+
+if(save=="RData"){
+
+file3<-paste(file3,".RData", sep="")
+file5<-paste(file5,".RData", sep="")
+
+save(datosf, file=file3)
+save(datosac, file=file5)
+
+load(file3)
+load(file5)
 }
+
 else{
-write.csv2(x=datosf, file = file5, fileEncoding = fileEncoding,
-row.names=row.names,na=na)
-write.csv2(x=datosac, file = file7, fileEncoding = fileEncoding,
-row.names=row.names,na=na)
-}
-
 
+file3<-paste(file3,".CSV", sep="")
+file5<-paste(file5,".CSV", sep="")
 
 if(dec=="."){
-datosf<-read.csv(file5, header=T, check.names=FALSE)
-datosac<-read.csv(file7, header=T, check.names=FALSE)
+write.csv(x=datosf, file = file3, row.names=row.names,na=na)
+write.csv(x=datosac, file = file3, row.names=row.names,na=na)
 }
 else{
-datosf<-read.csv2(file5, header=T, check.names=FALSE)
-datosac<-read.csv2(file7, header=T, check.names=FALSE)
+write.csv2(x=datosf, file = file3, row.names=row.names,na=na)
+write.csv2(x=datosac, file = file5, row.names=row.names,na=na)
 }
+
+if(dec=="."){
+datosf<-read.csv(file3, header=T, check.names=FALSE)
+datosac<-read.csv(file5, header=T, check.names=FALSE)
+}
+else{
+datosf<-read.csv2(file3, header=T, check.names=FALSE)
+datosac<-read.csv2(file5, header=T, check.names=FALSE)
+}
+
+}
+
+
+
+
 }
 
 
@@ -242,23 +281,39 @@ species<-cbind(c("Sum","Mean"),species)
 
 }
 
-if(matrix==FALSE) elements<-1 else elements<-elements
+if(format=="B") elements<-1 else elements<-elements
 
 if(elements==0){
 }
 else{
+
+if(save=="RData"){
+
+file3<-paste(file3,".RData", sep="")
+file5<-paste(file5,".RData", sep="")
+
+save(datosf, file=file3)
+save(datosac, file=file5)
+}
+
+
+else{
+
+file3<-paste(file3,".CSV", sep="")
+file5<-paste(file5,".CSV", sep="")
+
 if(dec=="."){
-write.csv(x=datosf, file = file5, fileEncoding = fileEncoding,
-row.names=row.names, na=na)
-write.csv(x=datosac, file = file7, fileEncoding = fileEncoding,
-row.names=row.names, na=na)
+write.csv(x=datosf, file = file3, row.names=row.names,na=na)
+write.csv(x=datosac, file = file3, row.names=row.names,na=na)
 }
 else{
-write.csv2(x=datosf, file = file5, fileEncoding = fileEncoding,
-row.names=row.names, na=na)
-write.csv2(x=datosac, file = file7, fileEncoding = fileEncoding,
-row.names=row.names, na=na)
+write.csv2(x=datosf, file = file3, row.names=row.names,na=na)
+write.csv2(x=datosac, file = file5, row.names=row.names,na=na)
 }
+
+}
+
+
 }
 
 
@@ -279,13 +334,13 @@ a<-dim(matriz)
 
 options(warn=-1)
 matriz1<-matriz
-matriz2<-matriz
-matriz3<-matriz
+#matriz2<-matriz
+#matriz3<-matriz
 matriz4<-matriz
 matriz5<-matriz
 matriz6<-matriz
 
-if(matrix==TRUE){
+if(format=="A"){
 maxLat1<-ceiling(max(x[,3]))
 minLat1<-floor(min(x[,3]))
 maxLon1<-ceiling(max(x[,2]))
@@ -313,7 +368,7 @@ if(length(r2)==2) r2<-r2[2] else r2<-r2
 if(method=="abundance") datosf<-datosf else jkjllk<-0
 
 
-if(matrix==TRUE){
+if(format=="A"){
 if(method=="incidence") datosf<-datosac else jkjllk<-0
 if(method=="accumulation") datosf<-datosac else jkjllk<-0
 }
@@ -372,7 +427,7 @@ else{
 
 for (h in seq(c1-f, c2+f, by = f)){
 
-if(matrix==TRUE){
+if(format=="A"){
 if(elements==0){
 
 if(method=="abundance"){
@@ -430,7 +485,7 @@ if(method=="abundance") cut<-5 else cut<-cut
 
 
 
-if(method=="abundance" & matrix==TRUE & dimy==0 & sum(as.numeric(datosx), na.rm=TRUE)>0
+if(method=="abundance" & format=="A" & dimy==0 & sum(as.numeric(datosx), na.rm=TRUE)>0
 & length(as.numeric(datosx))>=2){
 salA<-vegan::estimateR(as.numeric(datosx))
 
@@ -480,19 +535,8 @@ temp4<-c(Longitude, Latitude, 1,salA[1], chao1, ACE, com)
 
 if(Longitude!=0 & Latitude!=0){
 values2<-rbind(values2,temp4)
-if(pred=="NaN") matriz3[z+2,h]<-(-9999) else matriz3[z+2,h]<-(dimy[2]-pred)
-if(pred=="NaN"){
-matriz2[z+2,h]<-(-9999)
-matriz3[z+2,h]<-(-9999)
-}
-else{
-matriz2[z+2,h]<-pred
-matriz3[z+2,h]<-(dimy[2]-pred)
-if(com<cutoffCompleteness){
-matriz2[z+2,h]<-(-9999)
-matriz3[z+2,h]<-(-9999)
-}
-}
+
+
 }
 
 }
@@ -576,19 +620,7 @@ com<-(dimy[2]*100/pred)
 
 temp4<-c(Longitude, Latitude, dimy[1],dimy[2], chao1, ACE, com)
 values2<-rbind(values2,temp4)
-if(pred=="NaN") matriz3[z+2,h]<-(-9999) else matriz3[z+2,h]<-(dimy[2]-pred)
-if(pred=="NaN"){
-matriz2[z+2,h]<-(-9999)
-matriz3[z+2,h]<-(-9999)
-}
-else{
-matriz2[z+2,h]<-pred
-matriz3[z+2,h]<-(dimy[2]-pred)
-if(com<cutoffCompleteness){
-matriz2[z+2,h]<-(-9999)
-matriz3[z+2,h]<-(-9999)
-}
-}
+
 
 
 if(pred=="NaN") matriz5[z+2,h]<-(-9999) else matriz5[z+2,h]<-com
@@ -691,19 +723,50 @@ fgg<-1
 
 if(method=="accumulation"){
 if(cut<cutoff){
-Methods<-c(NA,NA,NA,NA)
-Methodssp<-c(NA,NA,NA,NA)
-sp2<-NA;sp3<-NA;sp4<-NA;sp5<-NA
-seMethods<-c(NA,NA,NA,NA)
-serandom<-NA;seexact<-NA;secoleman<-NA;serarefaction<-NA
+if(estimator==0){
+Methods<-c(NA,NA)
+Methodssp<-c(NA,NA)
+sp2<-NA;sp3<-NA
+seMethods<-c(NA,NA)
+serandom<-NA;seexact<-NA
+}
+else{
+Methods<-c(NA)
+Methodssp<-c(NA)
+sp2<-NA;sp3<-NA
+seMethods<-c(NA)
+serandom<-NA;seexact<-NA
+}
+
 }
 else{
 
 
-
+if(estimator==0 | estimator==2){
 cu<- vegan::specaccum(datosx, method="random", permutations = 200)
 datosc<-data.frame(cu$richness, cu$sites)
-if(curve=="Clench") modelo<-try(nls(cu.richness ~ A*cu.sites/(1+B*cu.sites), data=datosc, trace=T), silent=T) else modelo<-try(nls(cu.richness ~ (A/B)*(1-exp((-B*cu.sites))), start=list(A=0.1, B=0.01),data=datosc, trace=T), silent=T)
+
+ymax<-max(datosc[,1],na.rm=T)
+ymin<-min(datosc[,1],na.rm=T)
+xmax<-max(datosc[,2],na.rm=T)
+xmin<-min(datosc[,2],na.rm=T)
+
+if(curve=="Clench"){
+modelo<-try(nls(cu.richness ~ A*cu.sites/(1+B*cu.sites), data=datosc, start=list(A=1, B=0.01)), silent=T)
+}
+
+if(curve=="Exponential"){
+modelo<-try(nls(cu.richness ~ (A)*(1-exp((-B*cu.sites))), data=datosc, start=list(A=ymax, B=0.01)), silent=T)
+}
+
+if(curve=="Saturation"){
+modelo<-try(nls(cu.richness~A*(1-exp(-B*(cu.sites-C))), data=datosc, trace=T, start=list(A=ymax, B=0.01, C=0)), silent=TRUE)
+}
+
+if(curve=="Rational"){
+modelo<-try(nls(cu.richness~(A+B*cu.sites)/(1+C*cu.sites), data=datosc, trace=T, start=list(A=1, B=1, C=0)), silent=TRUE)
+}
+
 res<-summary(modelo)
 if(res[1]=="1"){
 cu2<-NA
@@ -711,6 +774,13 @@ serandom<-NA
 }
 else{
 cu2<-res$parameters[1,1]/res$parameters[2,1]
+if(curve=="Saturation" | curve=="Exponential"){
+cu2<-res$parameters[1,1]
+}
+if(curve=="Rational"){
+cu2<-res$parameters[2,1]/res$parameters[3,1]
+}
+
 if(cu2<0){
 cu2<-NA
 sp2<-NA
@@ -720,16 +790,45 @@ else{
 cu2<-cu2
 leng<-length(cu$sites)
 sp2<-cu$richness[leng]-cu$richness[leng-1]
-serandom<-sd(c((res$parameters[1,1]/res$parameters[2,1]),
-(res$parameters[1,1]+res$parameters[2,1])/(res$parameters[2,1]+res$parameters[2,2]),
-(res$parameters[1,1]-res$parameters[2,1])/(res$parameters[2,1]-res$parameters[2,2])))/sqrt(3)
+
+if(curve=="Clench"){res1<-datosc[,1]-(res$coefficients[1,1]*datosc[,2])/(1+res$coefficients[2,1]*datosc[,2])}
+if(curve=="Exponential"){res1<-datosc[,1]-(res$coefficients[1,1])*(1-exp((-res$coefficients[2,1]*datosc[,2])))}
+if(curve=="Saturation"){res1<-datosc[,1]-(res$coefficients[1,1]*(1-exp(-res$coefficients[2,1]*(datosc[,2]-res$coefficients[3,1]))))}
+if(curve=="Rational"){res1<-datosc[,1]-(res$coefficients[1,1]+res$coefficients[2,1]*datosc[,2])/(1+res$coefficients[3,1]*datosc[,2])}
+
+serandom<-sqrt(sum((res1)^2)/length(res1))
+
+R2random<-1-var(res1, na.rm=T)/var(datosc[,1], na.rm=T)
+}
 }
 }
 
-
+if(estimator==0 | estimator==1){
 cu<- vegan::specaccum(datosx, method="exact")
 datosc<-data.frame(cu$richness, cu$sites)
-if(curve=="Clench") modelo<-try(nls(cu.richness ~ A*cu.sites/(1+B*cu.sites), data=datosc, trace=T), silent=T) else modelo<-try(nls(cu.richness ~ (A/B)*(1-exp((-B*cu.sites))), start=list(A=0.1, B=0.01),data=datosc, trace=T), silent=T)
+
+ymax<-max(datosc[,1],na.rm=T)
+ymin<-min(datosc[,1],na.rm=T)
+xmax<-max(datosc[,2],na.rm=T)
+xmin<-min(datosc[,2],na.rm=T)
+
+if(curve=="Clench"){
+modelo<-try(nls(cu.richness ~ A*cu.sites/(1+B*cu.sites), data=datosc, start=list(A=1, B=0.01)), silent=T)
+}
+
+if(curve=="Exponential"){
+modelo<-try(nls(cu.richness ~ (A)*(1-exp((-B*cu.sites))), data=datosc, start=list(A=ymax, B=0.01)), silent=T)
+}
+
+if(curve=="Saturation"){
+modelo<-try(nls(cu.richness~A*(1-exp(-B*(cu.sites-C))), data=datosc, trace=T, start=list(A=ymax, B=0.01, C=0)), silent=TRUE)
+}
+
+if(curve=="Rational"){
+modelo<-try(nls(cu.richness~(A+B*cu.sites)/(1+C*cu.sites), data=datosc, trace=T, start=list(A=1, B=1, C=0)), silent=TRUE)
+}
+
+
 res<-summary(modelo)
 if(res[1]=="1"){
 cu3<-NA
@@ -737,6 +836,12 @@ seexact<-NA
 }
 else{
 cu3<-res$parameters[1,1]/res$parameters[2,1]
+if(curve=="Saturation" | curve=="Exponential"){
+cu3<-res$parameters[1,1]
+}
+if(curve=="Rational"){
+cu3<-res$parameters[2,1]/res$parameters[3,1]
+}
 if(cu3<0){
 cu3<-NA
 sp3<-NA
@@ -746,74 +851,52 @@ else{
 cu3<-cu3
 leng<-length(cu$sites)
 sp3<-cu$richness[leng]-cu$richness[leng-1]
-seexact<-sd(c((res$parameters[1,1]/res$parameters[2,1]),
-(res$parameters[1,1]+res$parameters[2,1])/(res$parameters[2,1]+res$parameters[2,2]),
-(res$parameters[1,1]-res$parameters[2,1])/(res$parameters[2,1]-res$parameters[2,2])))/sqrt(3)
+
+
+if(curve=="Clench"){res1<-datosc[,1]-(res$coefficients[1,1]*datosc[,2])/(1+res$coefficients[2,1]*datosc[,2])}
+if(curve=="Exponential"){res1<-datosc[,1]-(res$coefficients[1,1])*(1-exp((-res$coefficients[2,1]*datosc[,2])))}
+if(curve=="Saturation"){res1<-datosc[,1]-(res$coefficients[1,1]*(1-exp(-res$coefficients[2,1]*(datosc[,2]-res$coefficients[3,1]))))}
+if(curve=="Rational"){res1<-datosc[,1]-(res$coefficients[1,1]+res$coefficients[2,1]*datosc[,2])/(1+res$coefficients[3,1]*datosc[,2])}
+
+seexact<-sqrt(sum((res1)^2)/length(res1))
+
+R2exact<-1-var(res1, na.rm=T)/var(datosc[,1], na.rm=T)
+}
 }
 }
 
-cu<- vegan::specaccum(datosx, method="coleman")
-datosc<-data.frame(cu$richness, cu$sites)
-if(curve=="Clench") modelo<-try(nls(cu.richness ~ A*cu.sites/(1+B*cu.sites), data=datosc, trace=T), silent=T) else modelo<-try(nls(cu.richness ~ (A/B)*(1-exp((-B*cu.sites))), start=list(A=0.1, B=0.01),data=datosc, trace=T), silent=T)
-res<-summary(modelo)
-if(res[1]=="1"){
-cu4<-NA
-secoleman<-NA
-}
-else{
-cu4<-res$parameters[1,1]/res$parameters[2,1]
-if(cu4<0){
-cu4<-NA
-sp4<-NA
-secoleman<-NA
-}
-else{
-cu4<-cu4
-leng<-length(cu$sites)
-sp4<-cu$richness[leng]-cu$richness[leng-1]
-secoleman<-sd(c((res$parameters[1,1]/res$parameters[2,1]),
-(res$parameters[1,1]+res$parameters[2,1])/(res$parameters[2,1]+res$parameters[2,2]),
-(res$parameters[1,1]-res$parameters[2,1])/(res$parameters[2,1]-res$parameters[2,2])))/sqrt(3)
-}
-}
-
-cu<- vegan::specaccum(datosx, method="rarefaction")
-datosc<-data.frame(cu$richness, cu$sites)
-if(curve=="Clench") modelo<-try(nls(cu.richness ~ A*cu.sites/(1+B*cu.sites), data=datosc, trace=T), silent=T) else modelo<-try(nls(cu.richness ~ (A/B)*(1-exp((-B*cu.sites))), start=list(A=0.1, B=0.01),data=datosc, trace=T), silent=T)
-res<-summary(modelo)
-if(res[1]=="1"){
-cu5<-NA
-serarefaction<-NA
-}
-else{
-cu5<-res$parameters[1,1]/res$parameters[2,1]
-if(cu5<0){
-cu5<-NA
-sp5<-NA
-serarefaction<-NA
-}
-else{
-cu5<-cu5
-leng<-length(cu$sites)
-sp5<-cu$richness[leng]-cu$richness[leng-1]
-serarefaction<-sd(c((res$parameters[1,1]/res$parameters[2,1]),
-(res$parameters[1,1]+res$parameters[2,1])/(res$parameters[2,1]+res$parameters[2,2]),
-(res$parameters[1,1]-res$parameters[2,1])/(res$parameters[2,1]-res$parameters[2,2])))/sqrt(3)
-}
-}
-
-Methods<-c(cu3,cu2,cu4,cu5)
-if(cut<cutoff) seMethods<-c(NA,NA,NA,NA) else seMethods<-c(serandom, seexact, secoleman, serarefaction)
+if(estimator==0){
+Methods<-c(cu3,cu2)
+if(cut<cutoff) seMethods<-c(NA,NA) else seMethods<-c(seexact, serandom)
 Methods[Methods < 0] <- NA
 seMethods[seMethods < 0] <- NA
-if(cut<cutoff) Methodssp<-c(NA,NA,NA,NA) else Methodssp<-c(sp3, sp2, sp4,sp5)
+if(cut<cutoff) Methodssp<-c(NA,NA) else Methodssp<-c(sp3, sp2)
 Methodssp[Methodssp < 0] <- NA
 }
+
+
+if(estimator==1){
+Methods<-c(cu3)
+if(cut<cutoff) seMethods<-c(NA) else seMethods<-c(seexact)
+Methods[Methods < 0] <- NA
+seMethods[seMethods < 0] <- NA
+if(cut<cutoff) Methodssp<-c(NA) else Methodssp<-c(sp3)
+Methodssp[Methodssp < 0] <- NA
 }
-else{
-fgg<-1
+
+if(estimator==2){
+Methods<-c(cu2)
+if(cut<cutoff) seMethods<-c(NA) else seMethods<-c(serandom)
+Methods[Methods < 0] <- NA
+seMethods[seMethods < 0] <- NA
+if(cut<cutoff) Methodssp<-c(NA) else Methodssp<-c(sp2)
+Methodssp[Methodssp < 0] <- NA
 }
 
+}
+}
+
+
 
 Methods[Methods < 0] <- NA
 
@@ -846,16 +929,16 @@ pred<-mean(Methods[estimator], na.rm=T)
 
 
 if(method=="accumulation"){
+
 if (estimator==0){
 slope<-mean(Methodssp, na.rm=T)
 pred<-mean(Methods, na.rm=T)
 }
 else{
-slope<-mean(Methodssp[estimator], na.rm=T)
-pred<-mean(Methods[estimator], na.rm=T)
+slope<-Methodssp
+pred<-Methods
 }
-}
-else{
+
 }
 
 com<-(dimy[2]*100/pred)
@@ -887,47 +970,85 @@ wuo<-1
 }
 
 if(method=="accumulation"){
-temp4<-c(Longitude, Latitude, dimy[1],dimy[2],cu2,cu3,cu4,cu5,sp2,sp3,sp4,sp5,com)
-cu2<-NA;cu3<-NA;cu4<-NA;cu5<-NA
-sp2<-NA;sp3<-NA;sp4<-NA;sp5<-NA
+
+if(estimator==0){
+
+
+if(!is.na(slope) & slope>cutoffSlope){
+com<-NA
+}
+if(!is.na(com) & com<cutoffCompleteness){
+com<-NA
+}
+temp4<-c(Longitude, Latitude, dimy[1],dimy[2],cu3,cu2,sp3,sp2,slope,com)
+cu2<-NA;cu3<-NA
+sp2<-NA;sp3<-NA
 values3<-rbind(values3,temp4)
 
-setemp4<-c(Longitude, Latitude, dimy[1],dimy[2],serandom,seexact,secoleman,serarefaction)
-serandom<-NA;seexact<-NA;secoleman<-NA;serarefaction<-NA
+setemp4<-c(Longitude, Latitude, dimy[1],dimy[2],seexact,serandom,R2exact,R2random)
+serandom<-NA;seexact<-NA; R2exact<-NA; R2random<-NA
 sevalues3<-rbind(sevalues3,setemp4)
 }
-else{
-wuo<-1
+
+if(estimator==1){
+if(!is.na(com) & com<cutoffCompleteness){
+com<-NA
 }
+if(!is.na(slope) & slope>cutoffSlope){
+com<-NA
+}
+temp4<-c(Longitude, Latitude, dimy[1],dimy[2],cu3,sp3,com)
+cu2<-NA;cu3<-NA
+sp2<-NA;sp3<-NA
+values3<-rbind(values3,temp4)
+
+setemp4<-c(Longitude, Latitude, dimy[1],dimy[2],seexact,R2exact)
+serandom<-NA;seexact<-NA;R2exact<-NA
+sevalues3<-rbind(sevalues3,setemp4)
+}
+
+if(estimator==2){
+if(!is.na(slope) & slope>cutoffSlope){
+com<-NA
+}
+if(!is.na(com) & com<cutoffCompleteness){
+com<-NA
+}
+temp4<-c(Longitude, Latitude, dimy[1],dimy[2],cu2,sp2,com)
+cu2<-NA;cu3<-NA
+sp2<-NA;sp3<-NA
+values3<-rbind(values3,temp4)
+
+setemp4<-c(Longitude, Latitude, dimy[1],dimy[2],serandom,R2random)
+serandom<-NA;seexact<-NA;R2random<-NA
+sevalues3<-rbind(sevalues3,setemp4)
+}
+
+
+
+
+
+}
+
 
 matriz1[z+2,h]<-dimy[2]
 matriz4[z+2,h]<-dimy[1]
-if(pred=="NaN") matriz3[z+2,h]<-(-9999) else matriz3[z+2,h]<-(dimy[2]-pred)
-if(pred=="NaN"){
-matriz2[z+2,h]<-(-9999)
-matriz3[z+2,h]<-(-9999)
-}
-else{
-matriz2[z+2,h]<-pred
-matriz3[z+2,h]<-(dimy[2]-pred)
-if(com<cutoffCompleteness){
-matriz2[z+2,h]<-(-9999)
-matriz3[z+2,h]<-(-9999)
-}
-}
 
-if(pred=="NaN") matriz5[z+2,h]<-(-9999) else matriz5[z+2,h]<-com
+
+if(is.na(pred)) matriz5[z+2,h]<-(-9999) else matriz5[z+2,h]<-com
 
 if(method=="accumulation"){
-if(slope=="NaN") matriz6[z+2,h]<-(-9999) else matriz6[z+2,h]<-slope
+if(is.na(slope)) matriz6[z+2,h]<-(-9999) else matriz6[z+2,h]<-slope
 
-if(pred=="NaN"){
-matriz2[z+2,h]<-(-9999)
+if(is.na(pred)){
+#matriz2[z+2,h]<-(-9999)
 }
 else{
-matriz2[z+2,h]<-pred
+#matriz2[z+2,h]<-pred
 if(slope>cutoffSlope){
-matriz2[z+2,h]<-(-9999)
+#matriz2[z+2,h]<-(-9999)
+matriz6[z+2,h]<-(-9999)
+matriz5[z+2,h]<-(-9999)
 }
 }
 }
@@ -967,26 +1088,27 @@ else{
 if(method=="accumulation"){
 values<-values3[-1,]
 sevalues<-sevalues3[-1,]
-colnames(values)<-c("Longitude", "Latitude", "Records","Actual","random", "exact", "coleman", "rarefaction", "Slope random", "Slope exact", "Slope coleman", "Slope rarefaction", "Completeness")
-colnames(sevalues)<-c("Longitude", "Latitude", "Records","Actual","serandom", "seexact", "secoleman", "serarefaction")
+
+if(estimator==0){
+colnames(values)<-c("Longitude", "Latitude", "Records","Observed.richness", "Richness.exact", "Richness.random", "Slope.exact", "Slope.random", "Mean.slope", "Completeness")
+colnames(sevalues)<-c("Longitude", "Latitude", "Records","Observed.richenss", "seexact", "serandom","R2.exact","R2.random")
+}
+
+if(estimator==1){
+colnames(values)<-c("Longitude", "Latitude", "Records","Observed.richness","Richness.exact", "Slope.exact","Completeness")
+colnames(sevalues)<-c("Longitude", "Latitude", "Records","Observed.richness","seexact","R2.exact")
+}
+
+if(estimator==2){
+colnames(values)<-c("Longitude", "Latitude", "Records","Observed.richness","Richness.random", "Completeness")
+colnames(sevalues)<-c("Longitude", "Latitude", "Records","Observed.richness","serandom","R2.random")
+}
+
 
 }
 else{
 }
 
-if (missing(jpg4)) jpg4="Correlation matrix.jpg" else jpg4=jpg4
-if (missing(pch)) pch=15 else pch=pch
-if (missing(cex)) cex=1.5 else cex=cex
-if (missing(cex.labels)) cex.labels=1.5 else cex.labels=cex.labels
-if (missing(pchcol)) pchcol="red" else pchcol=pchcol
-
-if(cormatrix==TRUE){
-if(jpg==TRUE) jpeg(filename = jpg4, width = 8000, height = 4000, units = "px", pointsize = 14, bg = "white", res = 600) else hhjhk<-1
-values10<-values[,-c(1,2,3)]
-pairs(values10,main="",cex.main=cex.main, cex=cex, pch=pch, cex.labels = cex.labels, col=pchcol)
-
-if(jpg==TRUE) dev.off() else hhjhk<-1
-}
 
 ZZ[1,1]<-end.times
 ZZ[2,1]<-"Saving files...."
@@ -994,44 +1116,69 @@ ZZ[2,2]<-""
 write.table(ZZ,"Inf.txt", row.names=FALSE,col.names=FALSE)
 
 
-if(dec=="."){
-write.csv(x=matriz1,file = file1, fileEncoding = fileEncoding,
-row.names=row.names,na=na)
-write.csv(x=matriz2,file = file2, fileEncoding = fileEncoding,
-row.names=row.names,na=na)
-write.csv(x=matriz3,file = file3, fileEncoding = fileEncoding,
-row.names=row.names,na=na)
-write.csv(x=matriz4,file = file8, fileEncoding = fileEncoding,
-row.names=row.names,na=na)
-write.csv(x=matriz5,file = file9, fileEncoding = fileEncoding,
-row.names=row.names,na=na)
-if(method=="accumulation") write.csv(x=matriz6,file = file10, fileEncoding = fileEncoding, row.names=row.names,na=na) else fdssdf<-0
-write.csv(x=species, file = file4, fileEncoding = fileEncoding,
-row.names=row.names,na=na)
-write.csv(x=values, file = file6, fileEncoding = fileEncoding,
-row.names=row.names,na="")
-write.csv(x=sevalues, file = file11, fileEncoding = fileEncoding,row.names=row.names,na="")
+if(save=="RData"){
+
+file1<-paste(file1,".RData", sep="")
+file6<-paste(file6,".RData", sep="")
+file7<-paste(file7,".RData", sep="")
+file8<-paste(file8,".RData", sep="")
+file2<-paste(file2,".RData", sep="")
+file4<-paste(file4,".RData", sep="")
+file9<-paste(file9,".RData", sep="")
+
+save(matriz1, file=file1)
+save(matriz4, file=file6)
+save(matriz5, file=file7)
+if(method=="accumulation"){
+save(matriz6,file = file8)
+}
+save(species, file = file2)
+save(values, file = file4)
+save(sevalues, file = file9)
+
 }
 else{
-write.csv2(x=matriz1,file = file1, fileEncoding = fileEncoding,
-row.names=row.names,na=na)
-write.csv2(x=matriz2,file = file2, fileEncoding = fileEncoding,
-row.names=row.names,na=na)
-write.csv2(x=matriz3,file = file3, fileEncoding = fileEncoding,
-row.names=row.names,na=na)
-write.csv2(x=matriz4,file = file8, fileEncoding = fileEncoding,
-row.names=row.names,na=na)
-write.csv2(x=matriz5,file = file9, fileEncoding = fileEncoding,
-row.names=row.names,na=na)
-if(method=="accumulation") write.csv2(x=matriz6,file = file10, fileEncoding = fileEncoding, row.names=row.names,na=na) else fds<-0
-write.csv2(x=species, file = file4, fileEncoding = fileEncoding,
-row.names=row.names,na=na)
-write.csv2(x=values, file = file6, fileEncoding = fileEncoding,row.names=row.names,na="")
-write.csv2(x=sevalues, file = file11, fileEncoding = fileEncoding,row.names=row.names,na="")
+
+file1<-paste(file1,".CSV", sep="")
+file6<-paste(file6,".CSV", sep="")
+file7<-paste(file7,".CSV", sep="")
+file8<-paste(file8,".CSV", sep="")
+file2<-paste(file2,".CSV", sep="")
+file4<-paste(file4,".CSV", sep="")
+file9<-paste(file9,".CSV", sep="")
+
+if(dec=="."){
+write.csv(x=matriz1, file = file1, row.names=row.names,na=na)
+write.csv(x=species, file = file2, row.names=row.names,na=na)
+write.csv(x=values, file = file4,  row.names=row.names,na=na)
+write.csv(x=matriz4, file = file6,  row.names=row.names,na=na)
+write.csv(x=matriz5, file = file7,  row.names=row.names,na=na)
+write.csv(x=sevalues, file = file9,  row.names=row.names,na=na)
+if(method=="accumulation"){
+write.csv(x=matriz6, file = file8,  row.names=row.names,na=na)
 }
 
 
-if(method=="accumulation") rty<-6 else rty<-5
+}
+else{
+write.csv2(x=matriz1, file = file1, row.names=row.names,na=na)
+write.csv2(x=species, file = file2,  row.names=row.names,na=na)
+write.csv2(x=values, file = file4,  row.names=row.names,na=na)
+write.csv2(x=matriz4, file = file6,  row.names=row.names,na=na)
+write.csv2(x=matriz5, file = file7,  row.names=row.names,na=na)
+write.csv2(x=sevalues, file = file9,  row.names=row.names,na=na)
+if(method=="accumulation"){
+write.csv2(x=matriz6, file = file8,  row.names=row.names,na=na)
+}
+
+}
+
+}
+
+
+
+
+if(method=="accumulation") rty<-4 else rty<-3
 
 d<-length(Area)
 AA<-Area[1]
@@ -1049,112 +1196,91 @@ datos1<-na.exclude(datos1)
 for (qw in 1:rty){
 
 if(qw==1){
-if(dec=="."){
-varscale<-read.csv(file8, header=F)
+
+if(save=="RData"){
+load(file6)
+varscale<-as.matrix(matriz4)
 }
 else{
-varscale<-read.csv2(file8, header=F)
+if(dec=="."){
+varscale<-read.csv(file6, header=F)
+}
+else{
+varscale<-read.csv2(file6, header=F)
+}
 }
 
-}
-else{
+
 }
 
 if(qw==2){
+
+if(save=="RData"){
+load(file1)
+varscale<-as.matrix(matriz1)
+}
+else{
 if(dec=="."){
 varscale<-read.csv(file1, header=F)
 }
 else{
 varscale<-read.csv2(file1, header=F)
 }
+}
+
 
 matrizz1<-varscale
-if(!is.null(end)){
-datos1<-replace(matrizz1, matrizz1>=end, end)
-datos1[1,]<-varscale[1,]
-datos1[,1]<-varscale[,1]
-varscale<-datos1
-rm(datos1)
-rm(matrizz1)
-codlegend<-paste(">",end)
-}
 
 }
-else{
-}
+
+
 
 if(qw==3){
+if(save=="RData"){
+load(file7)
+varscale<-as.matrix(matriz5)
+}
+else{
 if(dec=="."){
-varscale<-read.csv(file2, header=F)
+varscale<-read.csv(file7, header=F)
 }
 else{
-varscale<-read.csv2(file2, header=F)
+varscale<-read.csv2(file7, header=F)
+}
 }
 
-matrizz1<-varscale
-if(!is.null(end)){
-datos1<-replace(matrizz1, matrizz1>=end, end)
-datos1[1,]<-varscale[1,]
-datos1[,1]<-varscale[,1]
-varscale<-datos1
-rm(datos1)
-rm(matrizz1)
-codlegend<-paste(">",end)
-}
 
-}
-else{
+
 }
 
 if(qw==4){
+if(save=="RData"){
+load(file8)
+varscale<-as.matrix(matriz6)
+}
+else{
 if(dec=="."){
-varscale<-read.csv(file3, header=F)
+varscale<-read.csv(file8, header=F)
 }
 else{
-varscale<-read.csv2(file3, header=F)
+varscale<-read.csv2(file8, header=F)
+}
 }
 
-}
-else{
-}
 
-if(qw==5){
-if(dec=="."){
-varscale<-read.csv(file9, header=F)
-}
-else{
-varscale<-read.csv2(file9, header=F)
-}
-
-}
-else{
-}
-
-if(qw==6){
-if(dec=="."){
-varscale<-read.csv(file10, header=F)
-}
-else{
-varscale<-read.csv2(file10, header=F)
-}
-
-}
-else{
 }
 
 ZZ[1,1]<-end.times
 ZZ[2,1]<-"Printing plot"
-if(qw==1) ZZ[2,2]<-main4 else hjjuy<-1
+if(qw==1) ZZ[2,2]<-main2 else hjjuy<-1
 if(qw==2) ZZ[2,2]<-main1 else hjjuy<-1
-if(qw==3) ZZ[2,2]<-main2 else hjjuy<-1
-if(qw==4) ZZ[2,2]<-main3 else hjjuy<-1
-if(qw==5) ZZ[2,2]<-main5 else hjjuy<-1
-if(qw==6) ZZ[2,2]<-main6 else hjjuy<-1
+if(qw==3) ZZ[2,2]<-main3 else hjjuy<-1
+if(qw==4) ZZ[2,2]<-main4 else hjjuy<-1
 
 write.table(ZZ,"Inf.txt", row.names=FALSE,col.names=FALSE)
 
 
-if (missing(inc)) inc=0.005 else inc=inc
+
 if (AA=="World"){
 if (missing(minLat)) minLat<--90 else minLat<-minLat
 if (missing(maxLat)) maxLat<-90 else maxLat<-maxLat
@@ -1194,14 +1320,10 @@ minLat<-minLat
 }
 }
 
-
-if (missing(trans)) trans=c(1,1) else trans<-trans
-if (missing(log)) log=c(0,0) else log<-log
-
 Lon<-as.numeric(varscale[1,-1])
 varLon<-as.numeric(varscale[1,-1])
 a<-length(Lon)
-a
+
 for (i in 1:a){
 if(i==1) varLon[i]<-((-180+Lon[i])/2) else varLon[i]<-((Lon[i-1]+Lon[i])/2)
 }
@@ -1209,7 +1331,7 @@ if(i==1) varLon[i]<-((-180+Lon[i])/2) else varLon[i]<-((Lon[i-1]+Lon[i])/2)
 Lat<-as.numeric(varscale[-1,1])
 varLat<-as.numeric(varscale[-1,1])
 a<-length(Lat)
-a
+
 for (i in 1:a){
 if(i==1) varLat[i]<-((90+Lat[i])/2) else varLat[i]<-((Lat[i-1]+Lat[i])/2)
 }
@@ -1291,43 +1413,7 @@ if (minLon<=-180) minLon<--180 else minLon<-minLon
 if (maxLat>=90) maxLat<-90 else maxLat<-maxLat
 if (minLat<=-90) minLat<--90 else minLat<-minLat
 
-if (missing(Area)) Area="World" else Area=Area
-if (missing(colbg)) colbg="transparent" else colbg=colbg
-if (missing(colcon)) colcon="transparent" else colcon=colcon
-if (missing(colf)) colf="black" else colf=colf
-if (missing(colfexc)) colfexc="black" else colfexc=colfexc
-if (missing(pro)) pro=TRUE else pro=pro
-if (missing(ylab)) ylab="Latitude" else ylab=ylab
-if (missing(xlab)) xlab="Longitude" else xlab=xlab
-if (missing(main1)) main1="Actual richness" else main1=main1
-if (missing(main2)) main2="Predicted richness" else main2=main2
-if (missing(main3)) main3="Residuals" else main3=main3
-if (missing(main4)) main4="Records" else main4=main4
-if (missing(main5)) main5="Completeness" else main5=main5
-if (missing(main6)) main6="Slope" else main6=main6
-
-if (missing(cex.lab)) cex.lab=1.4 else cex.lab=cex.lab
-if (missing(cex.axis)) cex.axis=1.2 else cex.axis=cex.axis
-if (missing(lwdP)) lwdP=0.6 else lwdP=lwdP
-if (missing(lwdC)) lwdC=0.1 else lwdC=lwdC
-if (missing(family)) family="sans" else family=family
-if (missing(font.main)) font.main=2 else font.main=font.main
-if (missing(font.lab)) font.lab=1 else font.lab=font.lab
-if (missing(font.axis)) font.axis=1 else font.axis=font.axis
-if (missing(lab)) lab=NULL else lab=lab
-if (missing(exclude)) exclude=NULL else exclude=exclude
-if (missing(colexc)) colexc="white" else colexc=colexc
 if (missing(varscale)) varscale=NULL else varscale=varscale
-color<-c("#FFFFFFFF", "#C8FFFFFF","#64FFFFFF","#00FFFFFF", "#64FF64FF","#C8FF00FF", "#FFFF00FF","#FFC800FF","#FF6400FF","#FF0000FF")
-if (missing(colscale)) colscale=color else colscale=colscale
-
-if (missing(breaks)) breaks=10 else breaks=breaks
-if (missing(xl)) xl=0 else xl=xl
-if (missing(xr)) xr=0 else xr=xr
-if (missing(yb)) yb=0 else yb=yb
-if (missing(yt)) yt=0 else yt=yt
-if (missing(ndigits)) ndigits=0 else ndigits=ndigits
-
 
 legend.max=max(ajuste)
 
@@ -1351,19 +1437,10 @@ y<-0
 rm(datos1)
 
 
-if (missing(jpg1)) jpg1="Actual richness.jpg" else jpg1=jpg1
-if (missing(jpg2)) jpg2="Predicted richness.jpg" else jpg2=jpg2
-if (missing(jpg3)) jpg3="Residuals.jpg" else jpg3=jpg3
-if (missing(jpg5)) jpg5="Records.jpg" else jpg5=jpg5
-if (missing(jpg6)) jpg6="Completeness.jpg" else jpg6=jpg6
-if (missing(jpg7)) jpg7="Slope.jpg" else jpg7=jpg7
-
-if(qw==1) file=jpg5 else hjjuy<-1
+if(qw==1) file=jpg2 else hjjuy<-1
 if(qw==2) file=jpg1 else hjjuy<-1
-if(qw==3) file=jpg2 else hjjuy<-1
-if(qw==4) file=jpg3 else hjjuy<-1
-if(qw==5) file=jpg6 else hjjuy<-1
-if(qw==6) file=jpg7 else hjjuy<-1
+if(qw==3) file=jpg3 else hjjuy<-1
+if(qw==4) file=jpg4 else hjjuy<-1
 
 if(jpg==TRUE) jpeg(filename = file, width = 8000, height = 4000, units = "px", pointsize = 14, bg = "white", res = 600) else hhjhk<-1
 
@@ -1413,39 +1490,8 @@ squishplot <- function(xlim,ylim,asp=1){
 } # end of function
 ###################
 
-if(qw==1 | qw==4){
-if(min(varscale[!varscale==-9999])==0) iniF<-0 else iniF<-legend.min
-}
 
-if(qw==2 | qw==3){
-if(!is.null(ini)){
-iniF<-ini
-}
-else{
-if(min(varscale[!varscale==-9999])==0) iniF<-0 else iniF<-legend.min
-}
-}
-
-
-if(qw==5){
-if (ComCut==TRUE){
-iniF<-cutoffCompleteness
-}
-else{
 if(min(varscale[!varscale==-9999])==0) iniF<-(-0.00001) else iniF<-legend.min
-}
-}
-
-if(qw==6){
-if (SlopeCut==TRUE){
-legend.max<-cutoffSlope
-if(min(varscale[!varscale==-9999])==0) iniF<-(-0.00001) else iniF<-legend.min
-}
-else{
-if(min(varscale[!varscale==-9999])==0) iniF<-(-0.00001) else iniF<-legend.min
-}
-}
-
 
 
 
@@ -1455,14 +1501,12 @@ xr<-195
 }
 
 
-if(qw==1) main=main4 else hjjuy<-1
+if(qw==1) main=main2 else hjjuy<-1
 if(qw==2) main=main1 else hjjuy<-1
-if(qw==3) main=main2 else hjjuy<-1
-if(qw==4) main=main3 else hjjuy<-1
-if(qw==5) main=main5 else hjjuy<-1
-if(qw==6){
-main=main6
-ndigits=2
+if(qw==3) main=main3 else hjjuy<-1
+if(qw==4){
+main=main4
+ndigits=ndigits+2
 color7<-rev(colscale[-1])
 colscale<-append(colscale[1],color7)
 }
@@ -1536,16 +1580,11 @@ sequ<-round(sequ, digits=ndigits)
 
 }
 
-if(qw==2 | qw==3){ 
-if(!is.null(end)){
-lensequ<-length(sequ)
-sequ[lensequ]<-codlegend
-}
-}
+
 
 
 plotrix::color.legend(xl=x1, yb=minLat, xr= x2,
-yt=maxLat, sequ, gradient="y", align="rb", cex=1.2, rect.col=colscale[-1])
+yt=maxLat, sequ, gradient="y", align="rb", cex=cex.legend, rect.col=colscale[-1])
 }
 else{
 if (yb==0){
@@ -1572,15 +1611,10 @@ sequ<-(seq(iniF,legend.max,by=legend.freq))
 sequ<-round(sequ, digits=ndigits)
 }
 
-if(qw==2 | qw==3){ 
-if(!is.null(end)){
-lensequ<-length(sequ)
-sequ[lensequ]<-codlegend
-}
-}
+
 
 plotrix::color.legend(xl=minLon, yb=y1, xr=maxLon, yt=y2, sequ,
-gradient="x", align="lt", cex=1.2, rect.col=colscale[-1])
+gradient="x", align="lt", cex=cex.legend, rect.col=colscale[-1])
 }
 
 if (AA=="World") {
@@ -1598,6 +1632,26 @@ par(tmp)
 
 if(jpg==TRUE) dev.off() else hhjk<-1
 }
+
+
+
+ObservedRichness<-matriz1
+Records<-matriz4
+Completeness<-matriz5
+Slope<-matriz6
+
+
+if(save=="RData"){
+save(ObservedRichness, file=file1)
+save(Records, file=file6)
+save(Completeness, file=file7)
+if(method=="accumulation"){
+save(Slope,file = file8)
+}
+}
+
+
+
 ZZ[1,1]<-"END"
 ZZ[1,2]<-""
 ZZ[2,1]<-""
@@ -1610,8 +1664,8 @@ rm(datosL)
 rm(datosx)
 rm(matriz)
 rm(matriz1)
-rm(matriz2)
-rm(matriz3)
+#rm(matriz2)
+#rm(matriz3)
 rm(matriz4)
 rm(matriz5)
 rm(matriz6)
